#!/usr/bin/env python

#****************************************************************************
#** $Id: table3.py,v 1.0 2002/06/15 17:33:53 frispete Exp $
#**
#** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
#**
#** This file is part of an example program for PyQt.  This example
#** program may be used, distributed and modified without limitation.
#**
#*****************************************************************************/

import sys
from qt import *
from qtsql import *

TRUE  = 1
FALSE = 0

#DB_QTDRIVER = "QPSQL7"
DB_QTDRIVER = "QMYSQL3"
DB_HOSTNAME = "server"
DB_DATABASE = "testdb"
DB_USERNAME = "xy"
DB_PASSWORD = "zzz"

class StatusPicker(QComboBox):
    def __init__(self, parent, name):
        self.index2id = []
        QComboBox.__init__(self, parent, name)
        cur = QSqlCursor("status")
        cur.select(cur.index("name"))
        i = 0
        while cur.next():
            self.insertItem(cur.value("name").toString(), i)
            index2id[i] = cur.value("id").toInt()
            i = i + 1

    def statusId(self):
        return index2id[self.currentItem()]

    def setStatusId(self, statusid):
        for i,j in self.index2id:
            if j == statusid:
                self.setCurrentItem(i)
                break

class CustomSqlEditorFactory(QSqlEditorFactory):
    def __init__(self, *args):
        apply(QSqlEditorFactory.__init__, (self,) + args)

    def createEditor(self, parent, field):
        if field.name() == "statusid":
            return StatusPicker(parent)
        else:
            return QSqlEditorFactory.createEditor(parent, field)

def createConnection():
    db = QSqlDatabase.addDatabase(DB_QTDRIVER)
    if db:
        db.setHostName(DB_HOSTNAME)
        db.setDatabaseName(DB_DATABASE)
        db.setUserName(DB_USERNAME)
        db.setPassword(DB_PASSWORD)
        if db.open():
            return TRUE
        else:
            print "Could not open testdb database"
            print db.lastError().driverText()
            print db.lastError().databaseText()
    else:
        print "Could not activate database driver"
    return FALSE

if __name__=='__main__':
    app = QApplication( sys.argv )

    if createConnection():
        staffCursor = QSqlCursor("staff")
        staffTable = QDataTable(staffCursor)
        propMap = QSqlPropertyMap()
        editorFactory = CustomSqlEditorFactory()
        propMap.insert("StatusPicker", "statusid")
        staffTable.installPropertyMap(propMap)
        staffTable.installEditorFactory(editorFactory)

        staffTable.addColumn("forename", "Forename")
        staffTable.addColumn("surname",  "Surname" )
        staffTable.addColumn("salary",   "Annual Salary")
        staffTable.addColumn("statusid", "Status")
        order = QStringList("surname")
        order.append("forename")
        staffTable.setSort(order)
        staffTable.refresh()
        staffTable.show()
        app.setMainWidget(staffTable)
        app.exec_loop()


